
/**
 * @(#)AgentItf.java	1.0 02/09/26
 *
 */

import java.io.Serializable;

/**
 * @(#)AgentItf.java	1.0 02/09/26
 *
 * The <code>AgentItf</code> interface should be implemented by any 
 * class whose instances are agents.
 * <p>
 *
 * Each agent is identified by a unique <code>name</code> and is created
 * on an agent server called the <code>home agent server</code>. A home agent
 * server is identified by a <code>host name</code> and a
 * <code>port number</code>.
 * <p>
 *
 * @author Sara Bouchenak
 * @author Christophe Rippert
 * @version 1.0, 09/26/02
 * @see     java.lang.Runnable
 * @see     java.io.Serializable
 */

public 
interface AgentItf
    extends Runnable, Serializable {

    /**
     * Initializes the agent with a <code>name</code>, and the 
     * <code>host name</code> and the <code>port number</code> of the 
     * agent server on which it is created.
     * <p>
     *
     * @param   name           the name of the agent.
     * @param   homeHostName   the host name of the agent server.
     * @param   homePortNumber the port number of the agent server.
     */
    void init(String name,
	      String homeHostName,
	      int homePortNumber);

    /**
     * Returns the agent's name.
     *
     * @return  the name of the agent.
     */
    String getName();

    /**
     * Returns the host name of the agent's home agent server.
     *
     * @return  host name of the home agent server.
     */
    String getHomeHostName();

    /**
     * Returns the port number of the agent's home agent server.
     *
     * @return  port number of the home agent server.
     */
    int getHomePortNumber();

    /**
     * Tests if the agent is mobile.
     *
     * @return  TRUE if the agent is instance of <code>MobileAgentItf</code>
     *          and FALSE otherwise.
     */
    boolean isMobile();

}
