
/**
 * @(#)MobileAgentItf.java	1.0 02/09/26
 *
 */


/**
 * @(#)MobileAgentItf.java	1.0 02/09/26
 *
 * The <code>MobileAgentItf</code> interface should be implemented by any 
 * class whose instances are mobile agents.
 * <p>
 *
 * A mobile agent can move to a remote agent server, come back to its home
 * agent server, wait for the arrival of another agent or join another agent.
 * <p>
 *
 * @author Sara Bouchenak
 * @version 1.0, 09/26/02
 * @see     AgentItf
 */

public 
interface MobileAgentItf
    extends AgentItf {

    /**
     * The mobile agent moves to an agent server identified by a 
     * <code>name</code> and a <code>port number</code>.
     *
     * @param  hostName  the target agent server's host name.
     * @param  hostPort  the target agent server's port number.
     */
    void moveTo(String hostName, int hostPort);

    /**
     * The mobile agent comes back to its home agent server.
     *
     */
    void comeBackHome();

    /**
     * The mobile agent waits for the arrival of another agent identified
     * by a <code>name</code>.
     * The mobile agent blocks until the other agent arrives.
     *
     * @param  otherAgentName  the name of the agent the mobile agent is 
     *                         waiting for.
     */
    void waitFor(String otherAgentName);

    /**
     * The mobile agent joins another agent identified by a <code>name</code>.
     * The mobile agent moves to the agent server hosting the target agent.
     *
     * @param  otherAgentName  the name of the agent the mobile agent is 
     *                         joining.
     */
    void meet(String otherAgentName);

    /**
     * Returns the host name of the agent's current agent server.
     *
     * @return  host name of the current agent server.
     */
    String getCurrentHostName();

    /**
     * Returns the port number of the agent's current agent server.
     *
     * @return  port number of the current agent server.
     */
    int getCurrentPortNumber();

    /**
     * Sets the value of the Returns the host name of the agent's 
     * current agent server name.
     *
     * @param  hostName name of the current agent server.
     */
    void setCurrentHostName(String hostName);


    /**
     * Sets the value of the Returns the host name of the agent's 
     * current agent server port.
     *
     * @param  portNumber port number of the current agent server.
     */
    void setCurrentPortNumber(int portNumber);

}
